@@ -51,9 +51,7 @@ def user_can_sudo():
 
 # the new style DB - if that exists we skip the legacy DB 
 dbpath = "/var/lib/command-not-found/commands.db"
-# the legacy DB shipped in the command-not-found-data package
-legacy_db = "/usr/share/command-not-found/commands.db"
-        
+
 
 class CommandNotFound(object):
 
@@ -61,6 +59,7 @@ class CommandNotFound(object):
     max_len = 256
     
     prefixes = (
+        "/snap/bin",
         "/bin",
         "/usr/bin",
         "/usr/local/bin",
@@ -78,8 +77,8 @@ class CommandNotFound(object):
         # a new style DB means we can skip loading the old legacy static DB
         if os.path.exists(dbpath):
             self.db = SqliteDatabase(dbpath)
-        elif os.path.exists(legacy_db):
-            self.db = SqliteDatabase(legacy_db)
+        else:
+            raise FileNotFoundError("Cannot find database")
         self.user_can_sudo = user_can_sudo()
         self.euid = posix.geteuid()
 
@@ -348,6 +347,17 @@ class CommandNotFound(object):
 
         if command in self.getBlacklist():
             return False
+
+        # python is special, on 20.04 and newer we should encourage
+        # people to use python3 only, and command-not-found depends on
+        # python3, so must be available
+        if command == "python":
+            print(_("Command '%s' not found, did you mean:") % command, file=self.output_fd)
+            print("")
+            print(_("  command '%s' from deb %s%s") % ("python3", "python3", ""), file=self.output_fd)
+            print("")
+            return True
+        
         packages = self.get_packages(command)
         snaps, mispell_snaps = self.get_snaps(command)
         logging.debug("got debs: %s snaps: %s" % (packages, snaps))
@@ -366,13 +376,5 @@ class CommandNotFound(object):
         elif len(packages) > 0 and len(snaps) > 0:
             self.advice_multi_mixed_packages(command, packages, snaps)
 
-        # python is special, on 18.04 and newer python2 is no longer installed
-        # which means there is no "python" binary. However python3 is installed
-        # by default. So in addition to the advise how to install it from the
-        # repo also add information that python3 is already installed.
-        if command == "python" and os.path.exists("/usr/bin/python3"):
-            print("You also have python3 installed, you can run 'python3' instead.")
-            print("")
-
         return (len(packages) > 0 or len(snaps) > 0 or
                 len(mispell_snaps) > 0 or len(mispell_packages) > 0)
